"""
/*
 *  Copyright (C) 2003-2010 Altair Engineering, Inc. All rights reserved.
 *
 *  ALTAIR ENGINEERING INC. Proprietary and Confidential. Contains Trade Secret
 *  Information. Not for use or disclosure outside ALTAIR and its licensed
 *  clients. Information contained herein shall not be decompiled, disassembled,
 *  duplicated or disclosed in whole or in part for any purpose. Usage of the
 *  software is only as explicitly permitted in the end user software license
 *  agreement.
 *
 *  Copyright notice does not imply publication.
 *
 */
"""

__doc__ = r"""
This module primarily exists to help the embedded interpreter import all the
python types. All attribute names that require *special* handling are maintained
in a dictionary as:
    Key <name> : Value <python_type>
    
    where:
        name *MUST* map to either attribute_def.at_name or resource_def.rs_name

Motivation:
    Since most of the object will be generated by the embedded python (aka C code)
    this gives a simple way to leverage the Python Data types to pass the infor-
    mation back to the embedded python. Which, then can use the excellent C API
    to retrieve the python type.
    
"""

import _base_types as pbs_types
from _svr_types import (_queue, _job, _server, _resv, _event, pbs_iter)
from _exc_types import *


#: IMPORTANT the keys are imported by the C code, make sure the mapping is
#: maintained.
#: TODO In future or time permits should add a constants to the internal _pbs_v1
#: module.
#:
EXPORTED_TYPES_DICT = {
                       'interactive' 		: pbs_types.pbs_int,
                       'block'			: pbs_types.pbs_int,
                       'Authorized_Users' 	: pbs_types.acl,
                       'Authorized_Groups' 	: pbs_types.acl,
                       'Authorized_Hosts' 	: pbs_types.acl,
                       'array_index' 		: pbs_types.pbs_int,
                       'array_indices_submitted': pbs_types.range,
                       'array_state_count'	: pbs_types.state_count,
                       'group_list' 		: pbs_types.group_list,
                       'managers' 		: pbs_types.acl,
                       'operators' 		: pbs_types.acl,
                       'User_List' 		: pbs_types.user_list,
                       'Shell_Path_List' 	: pbs_types.path_list,
                       'Output_Path' 		: pbs_types.path,
                       'Error_Path' 		: pbs_types.path,
                       'Priority' 		: pbs_types.priority,
                       'Job_Name' 		: pbs_types.name,
                       'Reserve_Name' 		: pbs_types.name,
                       'Join_Path' 		: pbs_types.join_path,
                       'default_qsub_arguments' : pbs_types.args,
                       'default_qdel_arguments' : pbs_types.args,
                       'select'             : pbs_types.select,
                       'schedselect'        : pbs_types.select,
                       'place'              : pbs_types.place,
                       'exec_host'          : pbs_types.exec_host,
                       'exec_vnode'         : pbs_types.exec_vnode,
                       'Checkpoint'         : pbs_types.checkpoint,
                       'depend'             : pbs_types.depend,
                       'Hold_Types'         : pbs_types.hold_types,
                       'Keep_Files'         : pbs_types.keep_files,
                       'Mail_Points'        : pbs_types.mail_points,
                       'Mail_Users'         : pbs_types.email_list,
                       'stagein'       	    : pbs_types.staging_list,
                       'stageout'           : pbs_types.staging_list,
                       'range'              : pbs_types.range,
                       'state_count'        : pbs_types.state_count,
                       'license_count'      : pbs_types.license_count,
                       'scheduler_iteration': pbs_types.duration,
                       'reserve_duration'   : pbs_types.duration,
                       'args'               : pbs_types.args,
                       'job_sort_formula'   : pbs_types.job_sort_formula,
                       'node_group_key'     : pbs_types.node_group_key,
                       'sandbox'	    : pbs_types.sandbox,
                       'pbs_version'        : pbs_types.version,
                       'software'           : pbs_types.software,
                       'acl_roots'          : pbs_types.acl,
                       'acl_hosts'          : pbs_types.acl,
                       'acl_resv_hosts'     : pbs_types.acl,
                       'acl_resv_groups'    : pbs_types.acl,
                       'acl_resv_users'     : pbs_types.acl,
                       'acl_groups'         : pbs_types.acl,
                       'acl_users'          : pbs_types.acl,
                       'state_count'        : pbs_types.state_count,
                       'server_state'       : pbs_types.server_state,
                       'route_destinations' : pbs_types.route_destinations,
		       'Variable_List'	    : pbs_types.pbs_env,	
		       'queue_type'	    : pbs_types.queue_type,	
		       'job_state'	    : pbs_types.job_state,	
                       'attr_descriptor'    : pbs_types.PbsAttributeDescriptor,
                       'generic_type'       : pbs_types._generic_attr,
                       'pbs_bool'           : pbs_types.pbs_bool,
                       'pbs_int'            : pbs_types.pbs_int,
                       'pbs_env'            : pbs_types.pbs_env,
                       'pbs_list'           : pbs_types.pbs_list,
                       'pbs_str'            : pbs_types.pbs_str,
                       'pbs_float'          : pbs_types.pbs_float,
                       'pbs_resource'       : pbs_types.pbs_resource,
                       'size'               : pbs_types.size,
                       'generic_time'       : pbs_types.duration,
                       'generic_acl'        : pbs_types.acl,
                       'queue'              : _queue,
                       'default_queue'      : _queue,
                       'job'                : _job,
                       'server'             : _server,
                       'resv'               : _resv,
                       'event'              : _event,
		       'pbs_iter'	    : pbs_iter,
                'EventIncompatibleError'    : EventIncompatibleError,
                'UnsetAttributeNameError'   : UnsetAttributeNameError,
                'BadAttributeValueTypeError': BadAttributeValueTypeError,
                'BadAttributeValueError'    : BadAttributeValueError,
                'UnsetResourceNameError'    : UnsetResourceNameError,
                'BadResourceValueTypeError' : BadResourceValueTypeError,
                'BadResourceValueError'     : BadResourceValueError
                       
                      }

